{{/* vim: set filetype=mustache: */}}
{{/*
Expand the name of the chart.
*/}}
{{- define "collector.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "collector.fullname" -}}
{{- if .Values.fullnameOverride -}}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- $name := default .Chart.Name .Values.nameOverride -}}
{{- if contains $name .Release.Name -}}
{{- .Release.Name | trunc 63 | trimSuffix "-" -}}
{{- else -}}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" -}}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "collector.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" -}}
{{- end -}}

{{/*
Create the name of the service account to use for creating or deleting the collector
*/}}
{{- define "collector.serviceAccount" -}}
{{- if .Values.telegraf.serviceAccount.create -}}
    {{ default (include "collector.fullname" .) .Values.telegraf.serviceAccount.name }}
{{- else -}}
    {{ default "default" .Values.telegraf.serviceAccount.name }}
{{- end -}}
{{- end -}}

{{/*
Create the name for the credentials secret.
*/}}
{{- define "collector.secretName" -}}
{{- if .Values.credentials.existingSecret -}}
  {{- .Values.credentials.existingSecret -}}
{{- else -}}
  {{ default (include "collector.fullname" .) .Values.credentials.name }}
{{- end -}}
{{- end -}}

{{/*
Compute if the telegraf-collector is enabled.
*/}}
{{- define "telegraf.telegrafEnabled" -}}
{{- $_ := set . "telegrafEnabled" (or
  (eq (.Values.telegraf.enabled | toString) "true")
  (and (eq (.Values.telegraf.enabled | toString) "-") (eq (.Values.global.enabled | toString) "true"))) -}}
{{- end -}}

{{/*
Compute the cloud provider telegraf is being run in.
*/}}
{{- define "telegraf.cloudProvider" -}}
{{- if hasKey .Values.telegraf "extraEnvironmentVars" }}
{{- if .Values.telegraf.extraEnvironmentVars.CLUSTER_CLOUD_PROVIDER -}}
  {{- $_ := set . "cloudProvider" .Values.telegraf.extraEnvironmentVars.CLUSTER_CLOUD_PROVIDER -}}
{{- else -}}
  {{- $_ := set . "cloudProvider" "NA" }}
{{- end -}}
{{- else -}}
{{- $_ := set . "cloudProvider" "NA" }}
{{- end -}}
{{- end -}}

{{/*
imagePullSecrets generates pull secrets from either string or map values.
A map value must be indexable by the key 'name'.
*/}}
{{- define "imagePullSecrets" -}}
{{- with .Values.global.imagePullSecrets -}}
imagePullSecrets:
{{- range . -}}
{{- if typeIs "string" . }}
  - name: {{ . }}
{{- else if index . "name" }}
  - name: {{ .name }}
{{- end }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Sets the telegraf deployment update strategy
*/}}
{{- define "telegraf.strategy" -}}
  {{- if .Values.telegraf.strategy }}
  strategy:
  {{- $tp := typeOf .Values.telegraf.strategy }}
  {{- if eq $tp "string" }}
    {{ tpl .Values.telegraf.strategy . | nindent 4 | trim }}
  {{- else }}
    {{- toYaml .Values.telegraf.strategy | nindent 4 }}
  {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets extra telegraf pod annotations
*/}}
{{- define "telegraf.annotations" -}}
  {{- if .Values.telegraf.annotations }}
      annotations:
        {{- $tp := typeOf .Values.telegraf.annotations }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.telegraf.annotations . | nindent 4 }}
        {{- else }}
          {{- toYaml .Values.telegraf.annotations | nindent 4 }}
        {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets extra telegraf PVC annotations
*/}}
{{- define "telegraf.persistentVolume.annotations" -}}
  {{- if .Values.telegraf.persistentVolume.annotations }}
      annotations:
        {{- $tp := typeOf .Values.telegraf.persistentVolume.annotations }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.telegraf.persistentVolume.annotations . | nindent 8 }}
        {{- else }}
          {{- toYaml .Values.telegraf.persistentVolume.annotations | nindent 8 }}
        {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets the telegraf affinity for pod placement
*/}}
{{- define "telegraf.affinity" -}}
  {{- if .Values.telegraf.affinity }}
      affinity:
        {{ $tp := typeOf .Values.telegraf.affinity }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.telegraf.affinity . | nindent 8 | trim }}
        {{- else }}
          {{- toYaml .Values.telegraf.affinity | nindent 8 }}
        {{- end }}
  {{ end }}
{{- end -}}

{{/*
Sets the telegraf topologySpreadConstraints for pod placement
*/}}
{{- define "telegraf.topologySpreadConstraints" -}}
  {{- if .Values.telegraf.topologySpreadConstraints }}
      topologySpreadConstraints:
        {{ $tp := typeOf .Values.telegraf.topologySpreadConstraints }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.telegraf.topologySpreadConstraints . | nindent 8 | trim }}
        {{- else }}
          {{- toYaml .Values.telegraf.topologySpreadConstraints | nindent 8 }}
        {{- end }}
  {{ end }}
{{- end -}}

{{/*
Sets the telegraf toleration for pod placement
*/}}
{{- define "telegraf.tolerations" -}}
  {{- if .Values.telegraf.tolerations }}
      tolerations:
      {{- $tp := typeOf .Values.telegraf.tolerations }}
      {{- if eq $tp "string" }}
        {{ tpl .Values.telegraf.tolerations . | nindent 8 | trim }}
      {{- else }}
        {{- toYaml .Values.telegraf.tolerations | nindent 8 }}
      {{- end }}
  {{- end }}
{{- end -}}

{{/*
Sets the telegraf node selector for pod placement
*/}}
{{- define "telegraf.nodeselector" -}}
  {{- if .Values.telegraf.nodeSelector }}
      nodeSelector:
      {{- $tp := typeOf .Values.telegraf.nodeSelector }}
      {{- if eq $tp "string" }}
        {{ tpl .Values.telegraf.nodeSelector . | nindent 8 | trim }}
      {{- else }}
        {{- toYaml .Values.telegraf.nodeSelector | nindent 8 }}
      {{- end }}
  {{- end }}
{{- end -}}

{{/*
securityContext for the telegraf pod level.
*/}}
{{- define "telegraf.securityContext.pod" -}}
  {{- if .Values.telegraf.securityContext.pod }}
      securityContext:
        {{- $tp := typeOf .Values.telegraf.securityContext.pod }}
        {{- if eq $tp "string" }}
          {{- tpl .Values.telegraf.securityContext.pod . | nindent 8 }}
        {{- else }}
          {{- toYaml .Values.telegraf.securityContext.pod | nindent 8 }}
        {{- end }}
  {{- else if not .Values.global.openshift }}
      securityContext:
        runAsNonRoot: true
        runAsGroup: {{ .Values.telegraf.gid | default 1000 }}
        runAsUser: {{ .Values.telegraf.uid | default 100 }}
        fsGroup: {{ .Values.telegraf.gid | default 1000 }}
  {{- end }}
{{- end -}}

{{/*
Sets the container resources if the user has set any.
*/}}
{{- define "telegraf.resources" -}}
  {{- if .Values.telegraf.resources -}}
          resources:
{{ toYaml .Values.telegraf.resources | indent 12}}
  {{ end }}
{{- end -}}

{{/*
securityContext for the telegraf container level.
*/}}
{{- define "telegraf.securityContext.container" -}}
  {{- if .Values.telegraf.securityContext.container}}
          securityContext:
            {{- $tp := typeOf .Values.telegraf.securityContext.container }}
            {{- if eq $tp "string" }}
              {{- tpl .Values.telegraf.securityContext.container . | nindent 12 }}
            {{- else }}
              {{- toYaml .Values.telegraf.securityContext.container | nindent 12 }}
            {{- end }}
  {{- else if not .Values.global.openshift }}
          securityContext:
            allowPrivilegeEscalation: false
            capabilities:
              drop:
                - ALL
  {{- end }}
{{- end -}}

{{/*
Inject extra environment vars in the format key:value, if populated
*/}}
{{- define "telegraf.extraEnvironmentVars" -}}
{{- if .extraEnvironmentVars -}}
{{- range $key, $value := .extraEnvironmentVars }}
- name: {{ printf "%s" $key | replace "." "_" | upper | quote }}
  value: {{ $value | quote }}
{{- end }}
{{- end -}}
{{- end -}}

{{/*
Inject extra environment populated by secrets, if populated
*/}}
{{- define "telegraf.extraSecretEnvironmentVars" -}}
{{- if .extraSecretEnvironmentVars -}}
{{- range .extraSecretEnvironmentVars }}
- name: {{ .envName }}
  valueFrom:
   secretKeyRef:
     name: {{ .secretName }}
     key: {{ .secretKey }}
{{- end -}}
{{- end -}}
{{- end -}}

{{/*
Set's which additional volumes should be mounted to the container.
*/}}
{{- define "telegraf.mounts" -}}
  {{- range .Values.telegraf.extraVolumes }}
            - name: userconfig-{{ .name }}
              readOnly: true
              mountPath: {{ .path | default "/telegraf/userconfig" }}/{{ .name }}
  {{- end }}
  {{- if .Values.telegraf.volumeMounts }}
    {{- toYaml .Values.telegraf.volumeMounts | nindent 12}}
  {{- end }}
{{- end -}}

{{/*
Iterates over any extra volumes the user may have specified (such as a secret
with TLS).
*/}}
{{- define "telegraf.volumes" -}}
  {{- range .Values.telegraf.extraVolumes }}
        - name: userconfig-{{ .name }}
          {{ .type }}:
          {{- if (eq .type "configMap") }}
            name: {{ .name }}
          {{- else if (eq .type "secret") }}
            secretName: {{ .name }}
          {{- end }}
            defaultMode: {{ .defaultMode | default 420 }}
  {{- end }}
  {{- if .Values.telegraf.volumes }}
    {{- toYaml .Values.telegraf.volumes | nindent 8}}
  {{- end }}
{{- end -}}
